==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-config/liblxqt-config-cursor/lxqt-config-cursor_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../../../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>Διαμόρφωση θέματος ποντικιού LXQt</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Επιλέξτε το θέμα του δρομέα που θέλετε να χρησιμοποιήσετε (κινηθείτε επάνω για προεπισκόπηση). &lt;b&gt;Χρειάζεται επανεκκίνηση της συνεδρίας LXQt μετά την αλλαγή&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="81"/>
        <source>&amp;Install New Theme...</source>
        <translation>&amp;Εγκατάσταση νέου θέματος...</translation>
    </message>
    <message>
        <source>&amp;Set Theme</source>
        <translation>&amp;Ορισμός θέματος</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="88"/>
        <source>&amp;Remove Theme</source>
        <translation>&amp;Αφαίρεση θέματος</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.cpp" line="208"/>
        <source>XCurTheme error</source>
        <translation>Σφάλμα του θέματος δρομέα X</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.cpp" line="209"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>Δεν μπορείτε να αφαιρέσετε το ενεργό θέμα!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../../../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>Παράθυρο διαλόγου</translation>
    </message>
    <message>
        <location filename="../../../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>Το LXQt δεν μπόρεσε να βρει κάποιο θέμα δρομέα. Θα χρησιμοποιηθεί ο εξ ορισμού δρομέας X11. Το LXQt έψαξε στους παρακάτω καταλόγους:</translation>
    </message>
    <message>
        <location filename="../../../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>Εμφάνιση...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../../../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>Όνομα</translation>
    </message>
    <message>
        <location filename="../../../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>Περιγραφή</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-config/liblxqt-config-cursor/lxqt-config-cursor_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../../../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>Διαμόρφωση θέματος ποντικιού LXQt</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Επιλέξτε το θέμα του δρομέα που θέλετε να χρησιμοποιήσετε (κινηθείτε επάνω για προεπισκόπηση). &lt;b&gt;Χρειάζεται επανεκκίνηση της συνεδρίας LXQt μετά την αλλαγή&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="81"/>
        <source>&amp;Install New Theme...</source>
        <translation>&amp;Εγκατάσταση νέου θέματος...</translation>
    </message>
    <message>
        <source>&amp;Set Theme</source>
        <translation type="vanished">&amp;Ορισμός θέματος</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="88"/>
        <source>&amp;Remove Theme</source>
        <translation>&amp;Αφαίρεση θέματος</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.cpp" line="212"/>
        <source>XCurTheme error</source>
        <translation>Σφάλμα του θέματος δρομέα X</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.cpp" line="213"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>Δεν μπορείτε να αφαιρέσετε το ενεργό θέμα!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../../../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>Παράθυρο διαλόγου</translation>
    </message>
    <message>
        <location filename="../../../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>Το LXQt δεν μπόρεσε να βρει κάποιο θέμα δρομέα. Θα χρησιμοποιηθεί ο εξ ορισμού δρομέας X11. Το LXQt έψαξε στους παρακάτω καταλόγους:</translation>
    </message>
    <message>
        <location filename="../../../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>Εμφάνιση...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../../../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>Όνομα</translation>
    </message>
    <message>
        <location filename="../../../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>Περιγραφή</translation>
    </message>
</context>
</TS>
